#!/usr/bin/env php
<?php
/**"
 +-----------------------------------------------------------------------+
 | export-contacts.sh                                                    |
 |                                                                       |
 | This script permit to import Roundcube user's address book in vCard   |
 | format.                                                               |
 |                                                                       |
 | Copyright (C) 2018, Cliss XXI                                         |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the LICENSE file for a full license statement.                    |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Jerome Lebleu <contact@cliss21.com>                           |
 +-----------------------------------------------------------------------+
"*/

// Unset memory limit during the import
ini_set('memory_limit', -1);

require_once 'common.php';

function print_usage()
{
    echo "Usage: import-contact.sh [options] username\n\n";
    echo "Options:\n";
    echo "    -h, --help        This help\n";
    echo "    -H, --host=domain Mail host (optional, e.g. imap.example.org)\n";
    echo "    -i, --input=path  Path to the .vcf file\n";
    echo "    -r, --replace     Replace existing contacts\n";
    echo "    -v, --verbose     Enable verbose mode\n";
    echo "    -d, --debug       Enable debug mode\n";
    echo "    -c, --create_user Create user account if needed\n";
    echo "    -b, --batch       Do not prompt for user, proceed anyway\n";
    echo "    -a, --aa_contacts Use automatic_addressbook instead of std\n";
    echo "                      contacts. Need plugin automatic_adressbook\n";
}

// get arguments
$args = rcube_utils::get_opt(array(
    'H' => 'host',
    'i' => 'input',
    'r' => 'replace:bool',
    'd' => 'debug:bool',
    'v' => 'verbose:bool',
    'h' => 'help:bool',
    'c' => 'create_user:bool',
    'b' => 'batch:bool',
    'a' => 'aa_contacts:bool',
));

if ('help' == $_SERVER['argv'][1] || $args['help']) {
    print_usage();
    exit(0);
} elseif (empty($args[0])) {
    echo "Missing required parameter.\n\n";
    print_usage();
    exit(1);
}

$username = trim($args[0]);

// define logging level
if ($args['debug']) {
    set_log_level('DEBUG');
} elseif ($args['verbose']) {
    set_log_level('INFO');
}

// check input file
$in = null;
if (!empty($args['input'])) {
    $in = fopen($args['input'], 'r');
    if (false === $in) {
        raise_err("Fail to open input file!");
    }
} else {
    // TODO: allow to use STDIN
    echo "--input parameter is currently required.\n\n";
    print_usage();
    exit(1);
}

// get a consistent mail_host for creating account on the fly
$default_host = $rcmail->config->get('default_host');
$mail_host = $args['host'] ?: $default_host;

// create account if needed
$rc_user = $rcmail->user->query($username, $mail_host);
if (!is_object($rc_user))
   {
       if ($args['create_user']) {
	      log_msg('INFO', "Create account $username with mail_host: $mail_host");
	      $rcmail->user->create($username, $mail_host);
	  } else {
	      raise_err(
		  "Account ".$username." on mail_host ".$mail_host
		  ." does not exists, use '-c' to create it on the fly\n");
	  }
   }

$contacts = new rcmail_contacts_utils($username, $args['host'], $args['aa_contacts']);
$contacts->import($in, $args['replace'], !$args['batch']);

if (!empty($args['input'])) {
    fclose($in);
}

?>
